@@ -47,6 +47,8 @@ class CodeAnalysis:
                    self._delNotesCodeLine, self._addEmptyCodeLine, self._delEmptyCodeLine
 
         for data in self.datas:
+            if len(data.get('diff')) == 0:
+                continue
             suffix = data['newPath'].split('.')[-1]
             content = data.get('diff').split('\n', maxsplit=1)[1]
             add_content = [_ for _ in content.split('\n') if _.startswith('+')]
@@ -57,13 +59,13 @@ class CodeAnalysis:
             self._delEmptyCodeLine = len(del_content) - len([_ for _ in del_content if len(_.replace('-', '')) != 0])
 
             # 扫描注释行
-            block, b_re, line, l_re = self._re_rule.get(suffix)
+            block, block_re, line, line_re = self._re_rule.get(suffix)
             if block and isinstance(block, bool):
                 continue
             block_content = block.findall(content)
-            add_notes_block, del_notes_block = self._replace_iter(block_content, b_re)
-            line_content = line.findall(content)
-            add_notes_line, del_notes_line = self._replace_iter(line_content, l_re)
+            add_notes_block, del_notes_block = self._replace_iter(block_content, block_re, True)
+            line_content = self._scan_line_content(add_content, del_content, line.findall(content))
+            add_notes_line, del_notes_line = self._replace_iter(line_content, line_re, False)
 
             # 注释行数
             self._addNotesCodeLine = len(add_notes_block) + len(add_notes_line)
@@ -74,16 +76,40 @@ class CodeAnalysis:
             self._delCodeLine = len(del_content) - self._delEmptyCodeLine - self._delNotesCodeLine
 
     @staticmethod
-    def _replace_iter(content_list: list, re_rule: list):
+    def _scan_line_content(add_list: list, delete_list: list, line_content_list: list):
+        add_surplus = list()
+        del_surplus = list()
+        for item in add_list:
+            try:
+                index = line_content_list.index(item.replace('+', '').replace('\t', ''))
+                del line_content_list[index]
+            except:
+                add_surplus.append(item)
+
+        for item in delete_list:
+            try:
+                index = line_content_list.index(item.replace('-', '').replace('\t', ''))
+                del line_content_list[index]
+            except:
+                del_surplus.append(item)
+
+        add_list = [_ for _ in add_list if _ not in add_surplus]
+        del_list = [_ for _ in delete_list if _ not in del_surplus]
+        return add_list + del_list
+
+    @staticmethod
+    def _replace_iter(content_list: list, notes: list, is_block: bool):
         add = list()
         delete = list()
         for content in content_list:
-            add.append(re_rule[0])
-            delete.append(re_rule[0])
             add += [_ for _ in content.split('\n') if _.startswith('+')]
             delete += [_ for _ in content.split('\n') if _.startswith('-')]
-        add = list() if len(add) == len(content_list) else add
-        delete = list() if len(delete) == len(content_list) else delete
+        if is_block:
+            temp_list = [notes[0] for i in range(len(content_list))]
+            if len(add) != 0:
+                add += temp_list
+            if len(delete) != 0:
+                delete += temp_list
         return add, delete
 
     def result(self):
